.. gromacs_py documentation master file, created by
   sphinx-quickstart on Fri Jun  1 16:36:00 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. toctree::
   :maxdepth: 2
   :caption: Table of Contents:

   readme
   install
   contributing
   pdb_manip_Coor
   pdb_manip_Multi_Coor
   pdb2pqr

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
